<?php

namespace Drupal\raven\Plugin\CspReportingHandler;

use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Url;
use Drupal\csp\Csp;
use Drupal\csp\Plugin\ReportingHandlerBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * CSP Reporting Plugin for a URI endpoint.
 *
 * @CspReportingHandler(
 *   id = "raven",
 *   label = "Sentry",
 *   description = @Translation("Reports will be sent to Sentry."),
 * )
 */
class Raven extends ReportingHandlerBase implements ContainerFactoryPluginInterface {

  /**
   * Raven logger service.
   *
   * @var \Drupal\raven\Logger\Raven
   */
  protected $logger;

  /**
   * {@inheritdoc}
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, $logger) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->logger = $logger;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('logger.raven')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function alterPolicy(Csp $policy) {
    $client = $this->logger->client;
    if (!$client) {
      return;
    }
    $query = ['sentry_key' => $client->public_key];
    if ($client->environment) {
      $query['sentry_environment'] = $client->environment;
    }
    if ($client->release) {
      $query['sentry_release'] = $client->release;
    }
    $policy->setDirective('report-uri', Url::fromUri(str_replace('/store/', '/security/', $client->server), ['query' => $query])->toString());
  }

}
